Beatgrid

Struct Beatgrid 

pub struct Beatgrid {
    pub version: Version,
    pub non_terminal_markers: Vec<NonTerminalMarker>,
    pub terminal_marker: TerminalMarker,
    pub footer: u8,
}
Represents the Serato BeatGrid tag.

It stores the Beatgrid as a sequence of zero or more non-terminal beatgrid markers and a single terminal beatgrid markers.

Example

use triseratops::tag::{Beatgrid, format::id3::ID3Tag};

// First, read the tag data from the ID3 GEOB tag (the tag name can be accessed using the
// Beatgrid::ID3_TAG), then parse the data like this:
fn parse(data: &[u8]) {
    let content = Beatgrid::parse_id3(data).expect("Failed to parse data!");
    println!("{:?}", content);
}

Fields

version: Version

The analysis version.

non_terminal_markers: Vec<NonTerminalMarker>

Zero or more non-terminal beatgrid markers.

terminal_marker: TerminalMarker

The terminal beatgrid marker.

footer: u8

A single footer byte that is apparently random (?).