pub struct TerminalMarker {
pub position: f32,
pub bpm: f32,
}Expand description
Represents the terminal beatgrid marker in the Serato BeatGrid tag.
The last beatgrid marker always has to be a terminal one. This is also the case if the tag only contains a single beatgrid marker.
Fields
position: f32The position in seconds.
bpm: f32The track’s beats per minute (BPM).